@@ -3,7 +3,7 @@ package Term::ANSIColor::Conditional;
 ## no critic (Modules::ProhibitAutomaticExportation)
 
 our $DATE = '2018-11-29'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict 'subs', 'vars';
 use warnings;
@@ -71,7 +71,7 @@ Term::ANSIColor::Conditional - Colorize text only if color is enabled
 
 =head1 VERSION
 
-This document describes version 0.002 of Term::ANSIColor::Conditional (from Perl distribution Term-ANSIColor-Conditional), released on 2018-11-29.
+This document describes version 0.003 of Term::ANSIColor::Conditional (from Perl distribution Term-ANSIColor-Conditional), released on 2018-11-29.
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,10 @@ How to determine "color is enabled":
 
 =head2 $COLOR => bool
 
+=head1 ENVIRONMENT
+
+=head2 COLOR
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Term-ANSIColor-Conditional>.
@@ -123,6 +127,10 @@ feature.
 
 L<Term::ANSIColor>
 
+These modules also respect the C<COLOR> environment variable:
+L<Color::ANSI::Util>, L<Term::ANSITable>, L<Data::Dump::Color>, L<JSON::Color>,
+L<YAML::Tiny::Color>, L<App::diffwc>, L<App::rsynccolor>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
